@@ -17,7 +17,7 @@ from shutil import which
 ''' This is PyRadio version this
     install.py was released for
 '''
-PyRadioInstallPyReleaseVersion = '0.9.3.11.22'
+PyRadioInstallPyReleaseVersion = '0.9.3.11.24'
 
 locale.setlocale(locale.LC_ALL, "")
 
@@ -44,7 +44,7 @@ except ImportError:
 
 VERSION = ''
 
-HAS_PIPX = True if shutil.which('pipx') else False
+HAS_PIPX = bool(shutil.which('pipx'))
 
 try:
     from rich import print
@@ -191,14 +191,11 @@ def fix_pyradio_win_exe():
 def is_pyradio_user_installed():
     if platform.system().lower().startswith('darwin'):
         return False
-    p = subprocess.Popen('which pyradio',
-                         shell=True,
-                         stdout=subprocess.PIPE,
-                         stderr=subprocess.DEVNULL
-                         )
-    ret = str(p.communicate()[0])
+    pyradio_path = shutil.which('pyradio')
+    if not pyradio_path:
+        return False
     home = os.path.expanduser('~')
-    return True if ret.startswith(home) else False
+    return pyradio_path.startswith(home)
 
 def is_process_running(process_name):
     """Check if there is any running process that contains the given name, excluding the current process."""
@@ -345,8 +342,7 @@ def get_github_long_description(
     if ret is None:
         if only_tag_name:
             return None
-        else:
-            return None, None
+        return None, None
 
     if only_tag_name:
         return returns[0][0]['name']
@@ -408,10 +404,8 @@ def get_devel_version():
     if long_descpr[0]:
         if long_descpr[1]:
             return 'PyRadio ' + long_descpr[1]
-        else:
-            return 'PyRadio ' + long_descpr[0]
-    else:
-        return None
+        return 'PyRadio ' + long_descpr[0]
+    return None
 
 def windows_put_devel_version():
     ''' not used '''
@@ -478,8 +472,7 @@ def get_a_linux_resource_opener():
         if which_str:
             if a_prog[1]:
                 return [which_str] + a_prog[1].split(' ')
-            else:
-                return [which_str]
+            return [which_str]
     return None
 
 def open_cache_dir():
@@ -572,7 +565,7 @@ class PyRadioCache():
             from rich.console import Console
             console = Console()
             if self.files:
-                max_len = max([len(x) for x in self._files]) + 4
+                max_len = max(len(x) for x in self._files) + 4
                 console.print('[magenta]PyRadio Cache[/magenta]:')
                 for i, n in enumerate(self._files):
                     if i < 5:
@@ -620,9 +613,9 @@ class PyRadioCache():
         if unit not in exponents_map:
             raise ValueError("Must select from \
             ['bytes', 'kb', 'mb', 'gb']")
-        else:
-            size = file_size / 1024 ** exponents_map[unit]
-            return round(size, 3)
+
+        size = file_size / 1024 ** exponents_map[unit]
+        return round(size, 3)
 
     def delete(self):
         ''' delete the cache dir and all file in it '''
@@ -648,7 +641,7 @@ class PyRadioCache():
 
     def exists(self):
         ''' does the cache dir exists? '''
-        return True if os.path.exists(self._cache_dir) else False
+        return os.path.exists(self._cache_dir)
 
     def is_empty(self):
         ''' is the cache dir empty?
@@ -656,7 +649,7 @@ class PyRadioCache():
             in the dir, or only the latest version ZIP file
             exists
         '''
-        return False if self.files else True
+        return not self.files
 
     def _read_cache(self):
         if self.exists():
@@ -756,7 +749,7 @@ class PythonExecutable():
             stderr=subprocess.PIPE
         )
         p.communicate()
-        self.is_debian = True if p.returncode == 0 else False
+        self.is_debian = p.returncode == 0
         return self.is_debian
 
     def _get_pythons(self):
@@ -773,7 +766,7 @@ class PythonExecutable():
                     'python 2.' in str_com:
                 self._python[0] = 'python'
                 break
-            elif 'Python 3.' in str_com or \
+            if 'Python 3.' in str_com or \
                     'python 3.' in str_com:
                 self._python[1] = 'python'
                 break
@@ -809,7 +802,7 @@ If you get en error, you have to add it to your PATH.
     def can_use(self):
         ''' Can I use the python I requested?
         '''
-        return True if self._python[self.requested_python_version - 2] else False
+        return self._python[self.requested_python_version - 2]
 
 class PyRadioUpdate():
 
@@ -1284,7 +1277,7 @@ class PyRadioUpdateOnWindows(PyRadioUpdate):
         ''' change to pyradio directory '''
         self._install_dir = os.path.join(self._dir, self._install_dir)
         if os.path.isdir(self._install_dir):
-           os.chdir(self._install_dir)
+            os.chdir(self._install_dir)
         else:
             print('Error: Failed to download PyRadio source code...\n')
             sys.exit(1)
@@ -1393,7 +1386,7 @@ if __name__ == '__main__':
         print_pipx_error()
         print_distro_packages()
         sys.exit()
-    use_logo = False if args.no_logo else True
+    use_logo = not args.no_logo
 
     if use_logo and not args.open_cache:
         print_pyradio_on()
@@ -1507,8 +1500,8 @@ if __name__ == '__main__':
             # is pyradio.exe in PATH
             ret = subprocess.call('pyradio -h 1>NUL 2>NUL', shell=True)
             if ret == 0 or not first_install:
-                    print('PyRadio is already installed.\n')
-                    sys.exit(1)
+                print('PyRadio is already installed.\n')
+                sys.exit(1)
         for a_module in (
                 'setuptools',
                 'windows-curses',
