@@ -689,16 +689,16 @@ def set_kb_cjk(value):
 def get_unicode_and_cjk_char(win, char):
     # logger.error(f'{char = }')
     def _decode_string(data):
+        """ convert bytes to string """
         encodings = ['utf-8', locale.getpreferredencoding(False), 'latin1']
         for enc in encodings:
-            try:
-                data = data.decode(enc)
-            except:
-                continue
-            break
-
-        assert type(data) != bytes  # Latin1 should have worked.
-        return data
+            if enc:      # in case locale.getpreferredencoding returns None
+                try:
+                    return data.decode(enc)
+                except UnicodeDecodeError:
+                    continue
+        # if nothing works, play safe
+        return data.decode('latin1', errors='replace')
 
     def get_check_next_byte(win):
         # logger.error(f'{win = }')
@@ -706,41 +706,40 @@ def get_unicode_and_cjk_char(win, char):
         enqueue_input(char)
         if 128 <= char <= 191:
             return char
-        else:
-            return None
-            raise UnicodeError
+        return None
+        raise UnicodeError
 
 
     set_kb_cjk(False)
     # logger.info('reseting kb_letter')
     set_kb_letter('')
     # logger.error(f'all {win = }')
-    bytes = []
+    bytes_data = []
     if char <= 127:
         ''' 1 byte '''
-        bytes.append(char)
+        bytes_data.append(char)
     #elif 194 <= char <= 223:
     elif 192 <= char <= 223:
-        ''' 2 bytes '''
-        bytes.append(char)
-        bytes.append(get_check_next_byte(win))
+        ''' 2 bytes_data '''
+        bytes_data.append(char)
+        bytes_data.append(get_check_next_byte(win))
     elif 224 <= char <= 239:
-        ''' 3 bytes '''
-        bytes.append(char)
-        bytes.append(get_check_next_byte(win))
-        bytes.append(get_check_next_byte(win))
+        ''' 3 bytes_data '''
+        bytes_data.append(char)
+        bytes_data.append(get_check_next_byte(win))
+        bytes_data.append(get_check_next_byte(win))
     elif 240 <= char <= 244:
-        ''' 4 bytes '''
-        bytes.append(char)
-        bytes.append(get_check_next_byte(win))
-        bytes.append(get_check_next_byte(win))
-        bytes.append(get_check_next_byte(win))
+        ''' 4 bytes_data '''
+        bytes_data.append(char)
+        bytes_data.append(get_check_next_byte(win))
+        bytes_data.append(get_check_next_byte(win))
+        bytes_data.append(get_check_next_byte(win))
     ''' no zero byte allowed '''
-    while 0 in bytes:
-        bytes.remove(0)
+    while 0 in bytes_data:
+        bytes_data.remove(0)
 
     try:
-        buf = bytearray(bytes)
+        buf = bytearray(bytes_data)
     except (ValueError, TypeError):
         return None
     out = _decode_string(buf)
@@ -763,22 +762,23 @@ def get_unicode_and_cjk_char(win, char):
 def add_l10n_to_functions_dict(functions):
     # logger.error(local_functions)
     local_keys = get_lkbkey()
+
     if local_keys is None:
         return functions
-    else:
-        local_functions = functions.copy()
-        new_keys = {}
-        # for key, value in local_functions.items():
-        #     logger.error(f'{key}: {value}')
-        #     for lkey, lvalue in local_keys.items():
-        #         if ord(lvalue) == key:
-        #             logger.error(f'    {lkey}: {lvalue}')
-        #             logger.error('      {} {}'.format(ord(lvalue), value))
-        #             new_keys[ord(lvalue)] = value
-        #             break
-        # logger.error('\n\n{}'.format(new_keys))
-        for n in new_keys:
-            local_functions[n] = new_keys[n]
+
+    local_functions = functions.copy()
+    new_keys = {}
+    # for key, value in local_functions.items():
+    #     logger.error(f'{key}: {value}')
+    #     for lkey, lvalue in local_keys.items():
+    #         if ord(lvalue) == key:
+    #             logger.error(f'    {lkey}: {lvalue}')
+    #             logger.error('      {} {}'.format(ord(lvalue), value))
+    #             new_keys[ord(lvalue)] = value
+    #             break
+    # logger.error('\n\n{}'.format(new_keys))
+    for key, value in new_keys.items():
+        local_functions[key] = value
     return local_functions
 
 def remove_l10n_from_global_functions(global_functions, shortcut_names):
@@ -853,7 +853,7 @@ class LetterProvider:
         Returns:
             int: The length of the longest layout string.
         """
-        return max([len(x) for x in self._layouts])
+        return max(len(x) for x in self._layouts)
 
     def get_layout(self):
         """
@@ -1270,9 +1270,11 @@ class LetterDisplay:
                 self._selection = 0
             elif char == curses.KEY_END and self._focused:
                 self._selection = len(self._letters) - 1
+
         if char == ord('?'):
-             return 2
-        elif char == ord('\x1b'):
+            return 2
+
+        if char == ord('\x1b'):
             return -1
 
         self.show()
@@ -1281,7 +1283,6 @@ class LetterDisplay:
 
 
 if __name__ == '__main__':
-    import json
     with open('/home/spiros/projects/my-gits/pyradio/pyradio/keyboard/classes.json', 'r', encoding='utf-8') as f:
         res = json.load(f)
     print('===> classes.py: res')
