@@ -52,8 +52,8 @@ def fix_chars(s):
     out = [s]
     from_str = ('\r', '\n', r'\"', r"\'")
     to_str = ('' , '', '"', "'")
-    for n in range(len(to_str)):
-        out.append(out[-1].replace(from_str[n], to_str[n]))
+    for n, item in enumerate(to_str):
+        out.append(out[-1].replace(from_str[n], item))
     return out[-1].strip()
 
 
@@ -173,7 +173,7 @@ class PyRadioTimer:
             self.current_time = None
         else:
             if logger.isEnabledFor(logging.DEBUG):
-                    logger.debug("Timer thread is not running.")
+                logger.debug("Timer thread is not running.")
 
     def update_time(self):
         """
@@ -249,15 +249,19 @@ class Log():
                  active_player_id,
                  get_web_song_title,
                  tts,
-                 mode
+                 mode,
+                 can_display_help_msg,
+                 program_restart
                  ):
-        self.program_restart = False
+        logger.error(f'getting {program_restart = }')
+        self.program_restart = program_restart
         self.error_msg = False
         self._active_width = 0
         self._desktop_notification_title = None
         self._desktop_notification_message = None
         self._repeat_notification = None
         self._mode = mode
+        self.can_display_help_msg  = can_display_help_msg
 
         self.msg = None
         self.suffix = None
@@ -294,8 +298,6 @@ class Log():
 
         self._add_chapter_function = None
 
-        self.can_display_help_msg = None
-
         self._check_start_time = None
 
         self._stop_using_buffering_msg = False
@@ -459,11 +461,11 @@ class Log():
                 with self.lock:
                     self._current_msg_id = msg_id
             with self.lock:
-                if msg_id < self._current_msg_id and msg_id > STATES.ANY:
+                if STATES.ANY < msg_id < self._current_msg_id:
                     if logger.isEnabledFor(logging.DEBUG):
                         logger.debug(f'refusing to print message with id {msg_id}, currently at {self._current_msg_id}')
                     return
-            if msg_id > STATES.ANY and msg_id < STATES.CONNECT_ERROR:
+            if STATES.ANY < msg_id < STATES.CONNECT_ERROR:
                 with self.lock:
                     if msg_id in (STATES.PLAYER_ACTIVATED, STATES.STOPPED):
                         self._current_msg_id = STATES.RESET
@@ -491,11 +493,14 @@ class Log():
             with self.lock:
                 # logger.error(f'{suffix =  }')
                 # logger.error(f'{counter =  }')
+                # logger.error(f'{self.program_restart = }')
                 if current_player_id != active_player_id:
                     if suffix != '' or suffix is not None or p_time is not None:
-                        if self.program_restart:
+                        if self.program_restart and msg:
                             self.program_restart = False
+                            # logger.error(f'reseting {self.program_restart = }')
                         else:
+                            # logger.error(f'\n\n********* setting {msg = } to None *********\n\n')
                             msg = None
                         counter = None
                     else:
@@ -573,7 +578,7 @@ class Log():
                     self.suffix = suffix
                 if counter is not None:
                     self.counter = counter
-                self.error_msg = True if error_msg else False
+                self.error_msg = bool(error_msg)
 
                 #if logger.isEnabledFor(logging.DEBUG):
                 #    logger.debug('after ----------------------------')
@@ -1228,6 +1233,7 @@ class RepeatDesktopNotification():
         self._cnf = config
         self._a_lock = self._start_time = None
         self.timeout = timeout
+        self.icon_path = None
 
     @property
     def start_time(self):
@@ -1319,7 +1325,7 @@ class RepeatDesktopNotification():
 
     def _populate_notification_command(self, a_notification_command, d_title, d_msg):
         notification_command = deepcopy(a_notification_command)
-        for i in range(0, len(notification_command)):
+        for i, _ in enumerate(notification_command):
             if 'TITLE' in notification_command[i]:
                 notification_command[i] = notification_command[i].replace('TITLE', d_title)
             if 'MSG' in notification_command[i]:
