@@ -45,7 +45,7 @@ purl = (
         https://sourceforge.net/projects/mpv-player-windows/files/latest/download
 '''
 zurl = [
-    'https://sourceforge.com/projects/mpv-player-windows/files/64bit/mpv-x86_64-20260104-git-a3350e2.7z/download',
+    'https://sourceforge.com/projects/mpv-player-windows/files/64bit/mpv-x86_64-20260111-git-9483d6e.7z/download',
     'https://sourceforge.net/projects/mplayerwin/files/MPlayer-MEncoder/r38151/mplayer-svn-38151-x86_64.7z/download'
 ]
 
@@ -97,18 +97,17 @@ def install_module(a_module, do_not_exit=False, print_msg=True):
             stderr=subprocess.DEVNULL)
         if ret == 0:
             break
+        if count < 5:
+            if print_msg:
+                print(f'  Download failed. Retrying [magenta]{count + 1}[/magenta]/[red]5[/red]')
         else:
-            if count < 5:
-                if print_msg:
-                    print(f'  Download failed. Retrying [magenta]{count + 1}[/magenta]/[red]5[/red]')
+            if print_msg:
+                print('Failed to download module...\nPlease check your internet connection and try again...')
             else:
-                if print_msg:
-                    print('Failed to download module...\nPlease check your internet connection and try again...')
-                else:
-                    print('Failed to download module "[magenta]{}[/magenta]"...\nPlease check your internet connection and try again...').format(a_module)
-                if do_not_exit:
-                    return False
-                sys.exit(1)
+                print('Failed to download module "[magenta]{}[/magenta]"...\nPlease check your internet connection and try again...').format(a_module)
+            if do_not_exit:
+                return False
+            sys.exit(1)
         return True
 
 try:
@@ -339,13 +338,11 @@ def download_player(output_folder=None, package=1, do_not_exit=False):
             patool_exec = join(site.USER_SITE.replace('site-packages', 'Scripts'), 'patool')
             if exists(patool_exec):
                 break
-            else:
-                patool_exec = glob.glob(join(dirname(environ['APPDATA']), '**', 'patool.exe'), recursive=True)
-                if patool_exec:
-                    patool_exec = patool_exec[0]
-                    break
-                else:
-                    install_module('patool', print_msg=False)
+            patool_exec = glob.glob(join(dirname(environ['APPDATA']), '**', 'patool.exe'), recursive=True)
+            if patool_exec:
+                patool_exec = patool_exec[0]
+                break
+            install_module('patool', print_msg=False)
             count += 1
             if count > 2:
                 break
@@ -453,7 +450,7 @@ def is_cpu_mpv_v3_compatible(print_flags=False):
             if print_flags:
                 print(n, '\t', 'nok')
 
-    return True if len(mpv_v3_cpu_flags) == count else False
+    return len(mpv_v3_cpu_flags) == count
 
 def _post_download(package, output_folder, do_not_exit):
 
@@ -544,7 +541,7 @@ def install_player(output_folder=None, package=0, do_not_exit=False):
             best_choise = ''
         else:
             best_choise = '([yellow]best choise[/yellow])'
-        if x == 'y' or x == '\n' or x == '\r':
+        if x in ('y', '\n', '\r'):
             x = ''
             msg = '''
 Please select an action:
